; ****************************************************************
function noticks, tickstring
; ****************************************************************
; Remove the leading and ending ticks from a Fits string

fin=strpos(tickstring,"'")
fou=strpos(tickstring,"'",/reverse_search)
if fou-fin lt 1 then begin
   fin=-1
   fou=strlen(tickstring)
endif
return, strmid(tickstring,fin+1,fou-fin-1)
end


; ****************************************************************
function headerscl, header, blank=blank, yscale=yscale, zscale=zscale, $
	minmax=minmax, xtitle=xtitle, ytitle=ytitle, ztitle=ztitle, $
	x0=x0, y0=y0, z0=z0, angle=arot, double_precision=double_precision
; ****************************************************************
; NAME:
;	HEADERSCL
;
; PURPOSE:
;	Read the axis definitions from a FITs header string
;
; INPUTS:
;	header: 	FITS header string

on_error,2                      ;Return to caller if an error occurs

; Declare types and constants
nstrings=21
fixedstr=["NAXIS", "NAXIS1", "NAXIS2", "NAXIS3",$
	  "CRPIX1", "CRPIX2", "CRPIX3", "CRVAL1", "CRVAL2", "CRVAL3", $
	  "CDELT1", "CDELT2", "CDELT3", "BLANK", "DATAMIN", "DATAMAX", $
	  "CD1_1", "CD2_2", "CD2_1", "CD1_2", "CROTA2"]
nnames=3
namestr= ["CTYPE1", "CTYPE2", "CTYPE3"]

; Defaults
valarr=[2.0,128.0,128.0,1.0,1.0,1.0,1.0,0.0,0.0,0.0,1.0,1.0,1.0,$
	-1.0,0.0,0.0,1.0,1.0,0.0,0.0,0.0]
if keyword_set(double_precision) then valarr=double(valarr)
namearr=make_array(nnames,value=' ')

; Scan the header
for i=0,nstrings-1 do begin
  tmpvar=sxpar(header,fixedstr[i],count=count)
  if (count gt 0) then valarr[i]=tmpvar
endfor
for i=0,nnames-1 do begin
  tmpvar=sxpar(header,namestr[i])
  if (count gt 0) then namearr[i]=tmpvar
endfor

; scale transformation
if (valarr[10] eq 1.0) and (valarr[16] ne 1.0) then begin
  if (abs(valarr[18]/valarr[16]) gt 0.02) then $
    print, 'Rotated coordinate system. Axes will be wrong!'
  if (valarr[8] gt 1.0) then $
    dx = valarr[16]/cos(valarr[8]*!dpi/180.0) $
  else dx=valarr[16]
endif else dx=valarr[10]

if (valarr[11] eq 1.0) and (valarr[17] ne 1.0) then begin
  if (abs(valarr[19]/valarr[17]) gt 0.02) then $
    print, 'Rotated coordinate system. Axes will be wrong!'
  dy=valarr[17]
endif else dy=valarr[11]

; Create the vectors
nx=fix(valarr[1])
if keyword_set(double_precision) then xscale=dblarr(nx) else xscale=fltarr(nx)
for i=0,nx-1 do xscale[i]=(i+1-valarr[4]) * dx + valarr[7]
x0=valarr[7]

if fix(valarr[0]) gt 1 then begin
 ny=fix(valarr[2])
 if keyword_set(double_precision) then yscale=dblarr(ny) else yscale=fltarr(ny)
 for i=0,ny-1 do yscale[i]=(i+1-valarr[5]) * dy + valarr[8]
 y0=valarr[8]
endif

if fix(valarr[0]) gt 2 then begin
 nz=fix(valarr[3])
 if keyword_set(double_precision) then zscale=dblarr(nz) else zscale=fltarr(nz)
 for i=0,nz-1 do zscale[i]=(i+1-valarr[6]) * valarr[12] + valarr[9]
 z0=valarr[9]
endif

blank=valarr[13]
if valarr[15] gt valarr[14] then minmax=[valarr[14],valarr[15]] $
	else minmax=0

; String treatment for the axis names
xtitle=noticks(namearr[0])
ytitle=noticks(namearr[1])
ztitle=noticks(namearr[2])
; Rotation
arot=[valarr[20],valarr[4],valarr[5],valarr[6]]

return, xscale
end
